import React from 'react'
import { withRouter } from 'react-router'
import { H3 } from '@pubsweet/ui'
import { B, SectionContent as Content, SectionHeader as Header } from '../ui/'

const SubmitText = ({ currentUser, teams, status, history }) => {
  const submitter = teams.find(team => team.role === 'submitter')
    ? teams.find(team => team.role === 'submitter').teamMembers[0]
    : null
  const reviewer = teams.find(team => team.role === 'reviewer')
    ? teams.find(team => team.role === 'reviewer').teamMembers[0]
    : null

  if (submitter && submitter.user.id === currentUser.id) {
    if (status === 'submission-error') {
      return (
        <React.Fragment>
          <Header>
            <H3>Correct errors</H3>
          </Header>
          <Content>
            <div>
              <p>
                {`Errors have been reported with this submission. You may edit the manuscript submission to correct these errors. When you are done, resubmit the manuscript.`}
              </p>
            </div>
          </Content>
        </React.Fragment>
      )
    }
    return null
  } else if (reviewer && reviewer.user.id === currentUser.id) {
    return (
      <React.Fragment>
        <Header>
          <H3>
            {status === 'submission-error'
              ? 'Correct errors'
              : 'Review submission'}
          </H3>
        </Header>
        <Content>
          <div>
            <p>
              {`You have been designated as the reviewer for this submission.`}
            </p>
            {status === 'in-review' && (
              <React.Fragment>
                <p>
                  {`Approve the submission for processing, or reject it to send it back to the submitter with comments. Alternatively, you may edit the manuscript submission yourself.`}
                </p>
                <p>
                  {`You will be responsible for approving the final web version. You must be an author of the manuscript. If you do not meet the requirements to review and approve this manuscript submission, please return the manuscript to the submitter, or contact the helpdesk.`}
                </p>
              </React.Fragment>
            )}
            {status === 'submission-error' && (
              <React.Fragment>
                <p>
                  {`Errors have been reported with this submission. If you are able to fix the errors, you may edit the manuscript submission yourself, then approve it to send it back to the helpdesk.`}
                </p>
                <p>
                  {`If you require the submitter to fix the errors, no further action is required; they have already been notified, and you will be contacted for an additional review once they have made their corrections.`}
                </p>
              </React.Fragment>
            )}
          </div>
        </Content>
      </React.Fragment>
    )
  } else if (currentUser.admin) {
    if (status !== 'submitted') {
      return (
        <React.Fragment>
          <Header>
            <H3>Attention Helpdesk staff</H3>
          </Header>
          <Content>
            <div>
              <p>
                <B>This manuscript has not yet been submitted!</B>
                {` Its status is '${status}'`}
              </p>
              <p>
                {`You may submit this manuscript, but this should only be done if you are changing the reviewer, or in some other special circumstance.`}
              </p>
            </div>
          </Content>
        </React.Fragment>
      )
    }
    return null
  }
  history.push('/')
  return null
}

export default withRouter(SubmitText)
